@@ -60,7 +60,8 @@ test_that('db_query_fields works with mock', {
           '\\(\\(SELECT 1 AS a, \'t\' AS b\\) AS "a"\\) ',
           'AS "zzz[0-9]+" LIMIT 0$'
         ),
-        next_uri='http://localhost:8000/query_1/1'
+        next_uri='http://localhost:8000/query_1/1',
+        query_id='query_1'
       ),
       mock_httr_response(
         'http://localhost:8000/v1/statement',
@@ -72,7 +73,21 @@ test_that('db_query_fields works with mock', {
             '\\(SELECT 1 AS a, \'t\' AS b\\) "a"',
           '\\) "zzz[0-9]+" WHERE 1 = 0$'
         ),
-        next_uri='http://localhost:8000/query_1/1'
+        next_uri='http://localhost:8000/query_1/1',
+        query_id='query_1'
+      ),
+      mock_httr_response(
+        'http://localhost:8000/v1/statement',
+        status_code=200,
+        state='QUEUED',
+        # For dbplyr 2.0.0
+        request_body=paste0(
+          '^SELECT \\* FROM \\(',
+            '\\(SELECT 1 AS a, \'t\' AS b\\) "a"',
+          '\\) "q[0-9]+" WHERE 1 = 0$'
+        ),
+        next_uri='http://localhost:8000/query_1/1',
+        query_id='query_1'
       ),
       mock_httr_response(
         'http://localhost:8000/v1/statement',
@@ -92,6 +107,17 @@ test_that('db_query_fields works with mock', {
         ),
         next_uri='http://localhost:8000/query_2/1',
       ),
+      mock_httr_response(
+        'http://localhost:8000/v1/statement',
+        status_code=200,
+        state='QUEUED',
+        # For dbplyr 2.0.0
+        request_body=paste0(
+          '^SELECT \\* FROM "__non_existent_table__" ',
+          'AS "q[0-9]+" WHERE 1 = 0$'
+        ),
+        next_uri='http://localhost:8000/query_2/1',
+      ),
       mock_httr_response(
         'http://localhost:8000/v1/statement',
         status_code=200,
@@ -110,6 +136,17 @@ test_that('db_query_fields works with mock', {
         ),
         next_uri='http://localhost:8000/query_3/1',
       ),
+      mock_httr_response(
+        'http://localhost:8000/v1/statement',
+        status_code=200,
+        state='FINISHED',
+        # For dbplyr 2.0.0
+        request_body=paste0(
+          '^SELECT \\* FROM "empty_table" AS "q[0-9]+"',
+          ' WHERE 1 = 0$'
+        ),
+        next_uri='http://localhost:8000/query_3/1',
+      ),
       mock_httr_response(
         'http://localhost:8000/v1/statement',
         status_code=200,
@@ -127,6 +164,17 @@ test_that('db_query_fields works with mock', {
           ' WHERE 1 = 0$'
         ),
         next_uri='http://localhost:8000/query_4/1',
+      ),
+      mock_httr_response(
+        'http://localhost:8000/v1/statement',
+        status_code=200,
+        state='QUEUED',
+        # For dbplyr 2.0.0
+        request_body=paste0(
+          '^SELECT \\* FROM "two_columns" AS "q[0-9]+"',
+          ' WHERE 1 = 0$'
+        ),
+        next_uri='http://localhost:8000/query_4/1',
       )
     ),
     `httr::GET`=mock_httr_replies(
@@ -158,7 +206,7 @@ test_that('db_query_fields works with mock', {
     ),
     `httr::DELETE`=function(url, body, ...) {
       mock_httr_response(
-        url='http://localhost:8000/query_1/1',
+        url='http://localhost:8000/v1/query/query_1',
         status_code=200,
         state=''
       )[['response']]
